/***********************************************************
 * $Id$
 *
 * FancyLibs GPSD Client
 *
 * Copyright (C) 2014 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSPSDCLIENTWATCH_H_
#define FANCYSPSDCLIENTWATCH_H_

#include <fancygpsdclientmessage.h>
#include <fancystring.h>
#include <fancyutctimestamp.h>

namespace Fancy {
namespace GpsdClient {

/**
 * <pre>
Name	Always?	Type	Description
class	Yes	string	Fixed: "WATCH"
enable	No	boolean	Enable (true) or disable (false) watcher mode. Default is true.
json	No	boolean	Enable (true) or disable (false) dumping of JSON reports. Default is false.
nmea	No	boolean	Enable (true) or disable (false) dumping of binary packets as pseudo-NMEA. Default is false.
raw	No	integer	Controls 'raw' mode. When this attribute is set to 1 for a channel, gpsd reports the unprocessed NMEA or AIVDM data stream from whatever device is attached. Binary GPS packets are hex-dumped. RTCM2 and RTCM3 packets are not dumped in raw mode. When this attribute is set to 2 for a channel that processes binary data, gpsd reports the received data verbatim without hex-dumping.
scaled	No	boolean	If true, apply scaling divisors to output before dumping; default is false.
split24	No	boolean	If true, aggregate AIS type24 sentence parts. If false, report each part as a separate JSON object, leaving the client to match MMSIs and aggregate. Default is false. Applies only to AIS reports.
pps	No	boolean	If true, emit a PPS bar when the device issues 1PPS. Intended to be used with the "nmea" and "raw" modes. Default is false. Note: this is an unstable experimental feature which may change or be removed without notice.
device	No	string	If present, enable watching only of the specified device rather than all devices. Useful with raw and NMEA modes in which device responses aren't tagged. Has no effect when used with enable:false.
remote	No	string	URL of the remote daemon reporting the watch set. If empty, this is a WATCH response from the local daemon.
 * </pre>
 */
class FANCYGPSDCLIENT_API Watch : public Message {

	bool enable;
	bool json;
	bool nmea;
	int32_t raw;
	bool scaled;
	bool timing;

public:
	typedef Fancy::ObjPtr<Watch> ptr_t;

	static ptr_t newInstance();
	static Fancy::Serializable::ptr_t newSerializableInstance();

	static const char *getSerialID_s();
	static const char *getSuperSerialID_s();
	const char *getSerialID() const;
	const char *getSuperSerialID() const;

	void writeFields(const ObjPtr<Serializer> &serializer) const;
	ObjPtr<Serializable> readFields(const ObjPtr<Serializer> &serializer, int64_t serialVersionUID);
	bool isEnable() const;
	void setEnable(bool enable);
	bool isJson() const;
	void setJson(bool json);
	bool isNmea() const;
	void setNmea(bool nmea);
	int32_t getRaw() const;
	void setRaw(int32_t raw);
	bool isScaled() const;
	void setScaled(bool scaled);
	bool isTiming() const;
	void setTiming(bool timing);

protected:
	Watch();
	virtual ~Watch();
};

} /* namespace GpsdClient */
} /* namespace Fancy */

#endif /* FANCYSPSDCLIENTWATCH_H_ */
